@@ -1,5 +1,7 @@
 PRAGMA foreign_keys = ON;
+DROP TABLE IF EXISTS concept_alias;
 DROP TABLE IF EXISTS concept;
+
 CREATE TABLE concept( id VARCHAR(255) PRIMARY KEY NOT NULL,
                       name_main varchar(255)  NOT NULL DEFAULT '',
                       definition TEXT,
@@ -8,9 +10,8 @@ CREATE TABLE concept( id VARCHAR(255) PRIMARY KEY NOT NULL,
                       FOREIGN KEY (broader_id) REFERENCES concept(id) ON DELETE SET NULL
 );
 
-DROP TABLE IF EXISTS concept_alias;
-CREATE TABLE concept_alias( alias_id VARCHAR(255) UNIQUE NOT NULL,
-                              concept_id VARCHAR(255) NOT NULL,
-                              FOREIGN KEY(concept_id) REFERENCES concept(id) ON DELETE CASCADE
-                             );
+CREATE TABLE concept_alias( alias_id VARCHAR(255) PRIMARY KEY NOT NULL,
+                            concept_id VARCHAR(255) NOT NULL,
+                            FOREIGN KEY(concept_id) REFERENCES concept(id) ON DELETE CASCADE
+                          );
 
